@@ -1,3 +1,10 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2015 Bastian Ilsø <bastianilso@gnome.org>
+// SPDX-FileCopyrightText: 2016 Kunaal Jain <kunaalus@gmail.com>
+// SPDX-FileCopyrightText: 2017 Danny Mølgaard <moelgaard.dmp@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -6,7 +13,7 @@ import Gtk from 'gi://Gtk?version=4.0';
 import Polari from 'gi://Polari';
 import Tp from 'gi://TelepathyGLib';
 
-import { setConsoleLogDomain } from 'console';
+import {setConsoleLogDomain} from 'console';
 
 import AccountsMonitor from './accountsMonitor.js';
 import * as Connections from './connections.js';
@@ -150,7 +157,7 @@ class Application extends Adw.Application {
         console.info(`Failed to activate service ${
             name}, starting manually`);
 
-        let proc = new Gio.Subprocess({ argv: [command] });
+        let proc = new Gio.Subprocess({argv: [command]});
 
         try {
             proc.init(null);
@@ -324,7 +331,7 @@ class Application extends Adw.Application {
         }];
         this.add_action_entries(actionEntries);
 
-        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
+        this._settings = new Gio.Settings({schema_id: 'org.gnome.Polari'});
         let action = this._settings.create_action('run-in-background');
         this.add_action(action);
 
@@ -338,7 +345,7 @@ class Application extends Adw.Application {
         action = this.lookup_action('leave-current-room');
         action.enabled = false;
 
-        for (const { name, accels } of actionEntries) {
+        for (const {name, accels} of actionEntries) {
             if (accels)
                 this.set_accels_for_action(`app.${name}`, accels);
         }
@@ -395,9 +402,9 @@ class Application extends Adw.Application {
 
         if (!this.active_window) {
             if (this._needsInitialSetup()) {
-                new InitialSetupWindow({ application: this });
+                new InitialSetupWindow({application: this});
             } else {
-                let window = new MainWindow({ application: this });
+                let window = new MainWindow({application: this});
                 window.connect('notify::active-room',
                     () => this.emit('room-focus-changed'));
                 window.connect('notify::is-active',
@@ -600,7 +607,7 @@ class Application extends Adw.Application {
                 this._untrackNominalNick(account);
                 account.set_nickname_async(nominalNick);
             });
-        this._nickTrackData.set(account, { tracker, contactsChangedId });
+        this._nickTrackData.set(account, {tracker, contactsChangedId});
     }
 
     _untrackNominalNick(account) {
@@ -618,7 +625,7 @@ class Application extends Adw.Application {
             return data;
 
         let params = account.getConnectionParams();
-        let { server, account: accountName, port } = params;
+        let {server, account: accountName, port} = params;
         console.info(`Failed to connect to ${server} with username ${
             accountName}`);
 
@@ -642,7 +649,7 @@ class Application extends Adw.Application {
 
     _restoreAccountName(account) {
         let accountName = this._getTrimmedAccountName(account);
-        let params = { account: new GLib.Variant('s', accountName) };
+        let params = {account: new GLib.Variant('s', accountName)};
         let asv = new GLib.Variant('a{sv}', params);
         account.update_parameters_vardict_async(asv, []);
     }
@@ -667,7 +674,7 @@ class Application extends Adw.Application {
         let nick = oldParams['account'].deep_unpack();
 
         console.info(`Retrying with nickname ${nick}_`);
-        let params = { account: new GLib.Variant('s', `${nick}_`) };
+        let params = {account: new GLib.Variant('s', `${nick}_`)};
         this._retryWithParams(account, new GLib.Variant('a{sv}', params));
         return true;
     }
@@ -786,9 +793,6 @@ class Application extends Adw.Application {
         let account = this._accountsMonitor.lookupAccount(accountPath);
         let dialog = new Connections.ConnectionProperties(account);
         dialog.transient_for = this.active_window;
-        dialog.connect('response', w => {
-            w.destroy();
-        });
         dialog.show();
     }
 
@@ -810,6 +814,8 @@ class Application extends Adw.Application {
 
     _onShowAbout() {
         let aboutParams = {
+            application_name: _('Polari'),
+            developer_name: 'Florian Müllner',
             developers: [
                 'Florian Müllner <fmuellner@gnome.org>',
                 'William Jon McCann <william.jon.mccann@gmail.com>',
@@ -828,6 +834,7 @@ class Application extends Adw.Application {
                 'unkemptArc99 <abhishekbhardwaj540@gmail.com>',
                 'Oscar Shrimpton <oscar.shrimpton.personal@gmail.com>',
                 'Daronion <stefanosdimos.98@gmail.com>',
+                'Georges Basile Stavracas Neto <georges.stavracas@gmail.com>',
             ],
             artists: [
                 'Sam Hewitt <hewittsamuel@gmail.com>',
@@ -846,7 +853,15 @@ class Application extends Adw.Application {
             application_icon: 'org.gnome.Polari',
             version: pkg.version,
             issue_url: 'https://gitlab.gnome.org/GNOME/polari/-/issues',
-            website: 'https://wiki.gnome.org/Apps/Polari',
+            website: 'https://apps.gnome.org/Polari',
+            release_notes: `
+              <ul>
+                <li>Adapt to latest GNOME design pattern</li>
+                <li>Improve visuals</li>
+                <li>Remove GNOME from networks list 😢</li>
+                <li>Fix user-online notifications</li>
+                <li>Fix selecting existing room in mobile view</li>
+              </ul>`,
 
             transient_for: this.active_window,
             modal: true,
