@@ -1,3 +1,10 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2014 Carlos Soriano <carlos.soriano89@gmail.com>
+// SPDX-FileCopyrightText: 2015 Bastian Ilso <bastianilso@gnome.org>
+// SPDX-FileCopyrightText: 2016 raresv <rares.visalom@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 import Gdk from 'gi://Gdk';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -9,8 +16,8 @@ import Polari from 'gi://Polari';
 import Tp from 'gi://TelepathyGLib';
 import Tpl from 'gi://TelepathyLogger';
 
-import { DropTargetIface } from './pasteManager.js';
-import { UserPopover } from './userList.js';
+import {DropTargetIface} from './pasteManager.js';
+import {UserPopover} from './userList.js';
 import UserStatusMonitor from './userTracker.js';
 import URLPreview from './urlPreview.js';
 import * as Utils from './utils.js';
@@ -53,7 +60,7 @@ class TextView extends Gtk.TextView {
             'indent-width-chars', 'indent-width-chars', 'indent-width-chars',
             GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             0, GLib.MAXUINT32, 0),
-        'indext-spacing': GObject.ParamSpec.uint(
+        'indent-spacing': GObject.ParamSpec.uint(
             'indent-spacing', 'indent-spacing', 'indent-spacing',
             GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             0, GLib.MAXUINT32, 0),
@@ -167,29 +174,22 @@ class TextView extends Gtk.TextView {
         let baseline = Math.floor(this._layout.get_baseline() / Pango.SCALE);
         let layoutY = y - baseline + Math.floor((layoutHeight - baseline) / 2) + 0.5;
 
-        const bounds = new Graphene.Rect();
-        bounds.init(MARGIN, y, width, 1);
-
         snapshot.save();
 
-        snapshot.translate(new Graphene.Point({ x: layoutX, y: layoutY }));
+        snapshot.translate(new Graphene.Point({x: layoutX, y: layoutY}));
         snapshot.append_layout(this._layout, this._dimColor);
 
         snapshot.restore();
 
-        const cr = snapshot.append_cairo(bounds);
-
         const [, color] = this.get_style_context().lookup_color('borders');
-        Gdk.cairo_set_source_rgba(cr, color);
 
-        cr.setLineWidth(1);
-        cr.moveTo(MARGIN, y);
-        cr.lineTo(layoutX - MARGIN, y);
-        cr.moveTo(layoutX + layoutWidth + MARGIN, y);
-        cr.lineTo(MARGIN + width, y);
-        cr.stroke();
+        const rect = new Graphene.Rect();
 
-        cr.$dispose();
+        rect.init(MARGIN, y, layoutX - 2 * MARGIN, 1);
+        snapshot.append_color(color, rect);
+
+        rect.init(layoutX + layoutWidth + MARGIN, y, width - layoutX - layoutWidth, 1);
+        snapshot.append_color(color, rect);
     }
 
     _onMarkSet(buffer, iter, mark) {
@@ -215,8 +215,8 @@ class ButtonTag extends Gtk.TextTag {
     };
 
     static [GObject.signals] = {
-        'clicked': { param_types: [GObject.TYPE_DOUBLE, GObject.TYPE_DOUBLE] },
-        'popup-menu': { param_types: [GObject.TYPE_DOUBLE, GObject.TYPE_DOUBLE] },
+        'clicked': {param_types: [GObject.TYPE_DOUBLE, GObject.TYPE_DOUBLE]},
+        'popup-menu': {param_types: [GObject.TYPE_DOUBLE, GObject.TYPE_DOUBLE]},
     };
 
     clicked(...coords) {
@@ -302,36 +302,31 @@ class ChatView extends Gtk.ScrolledWindow {
     };
 
     constructor(room) {
-        super({ hscrollbar_policy: Gtk.PolicyType.NEVER, vexpand: true });
+        super({hscrollbar_policy: Gtk.PolicyType.NEVER, vexpand: true});
 
         this.add_css_class('polari-chat-view');
 
         this._actionGroup = new Gio.SimpleActionGroup();
         this.insert_action_group('chatlog', this._actionGroup);
-
-        let action;
-        action = new Gio.SimpleAction({
-            name: 'open-url',
-            parameter_type: new GLib.VariantType('s'),
-        });
-        action.connect('activate',
-            (a, params) => Utils.openURL(params.unpack()));
-        this._actionGroup.add_action(action);
-
-        action = new Gio.SimpleAction({
-            name: 'copy-url',
-            parameter_type: new GLib.VariantType('s'),
-        });
-        action.connect('activate', (a, params) => {
-            const clipboard = this.get_clipboard();
-            clipboard.set(params.unpack());
-        });
-        this._actionGroup.add_action(action);
+        this._actionGroup.add_action_entries([
+            {
+                name: 'open-url',
+                parameter_type: 's',
+                activate: (a, params) => Utils.openURL(params.unpack()),
+            },
+            {
+                name: 'copy-url',
+                parameter_type: 's',
+                activate: (a, params) =>
+                    this.get_clipboard().set(params.unpack()),
+            },
+        ]);
 
         this._view = new TextView({
             editable: false, cursor_visible: false,
             wrap_mode: Gtk.WrapMode.WORD_CHAR,
             right_margin: MARGIN,
+            bottom_margin: MARGIN,
             indent_width_chars: MAX_NICK_CHARS,
             indent_spacing: NICK_SPACING,
         });
@@ -386,7 +381,7 @@ class ChatView extends Gtk.ScrolledWindow {
         this._view.add_controller(this._clickGesture);
 
         this._room = room;
-        this._state = { lastNick: null, lastTimestamp: 0, lastStatusGroup: 0 };
+        this._state = {lastNick: null, lastTimestamp: 0, lastStatusGroup: 0};
         this._joinTime = 0;
         this._hoveredButtonTags = [];
         this._needsIndicator = true;
@@ -394,7 +389,7 @@ class ChatView extends Gtk.ScrolledWindow {
         this._pendingLogs = [];
         this._initialPending = [];
         this._backlogTimeoutId = 0;
-        this._statusCount = { left: 0, joined: 0, total: 0 };
+        this._statusCount = {left: 0, joined: 0, total: 0};
 
         this._activeNickColor = new Gdk.RGBA();
         this._inactiveNickColor = new Gdk.RGBA();
@@ -627,7 +622,7 @@ class ChatView extends Gtk.ScrolledWindow {
         if (this._logWalker.is_end())
             return this._pendingLogs.splice(0);
 
-        let { nick, messageType: type } = this._pendingLogs[0];
+        let {nick, messageType: type} = this._pendingLogs[0];
         let maxNum = this._pendingLogs.length - this._initialPending.length;
         for (let i = 0; i < maxNum; i++) {
             if (this._pendingLogs[i].nick !== nick ||
@@ -669,7 +664,7 @@ class ChatView extends Gtk.ScrolledWindow {
 
         let indicatorIndex = pending.length - numInitialPending;
 
-        let state = { lastNick: null, lastTimestamp: 0 };
+        let state = {lastNick: null, lastTimestamp: 0};
         let iter = this._view.buffer.get_start_iter();
 
         for (let i = 0; i < pending.length; i++) {
@@ -821,7 +816,7 @@ class ChatView extends Gtk.ScrolledWindow {
 
         const menu = new Gtk.PopoverMenu({
             position: Gtk.PositionType.BOTTOM,
-            pointing_to: new Gdk.Rectangle({ x, y }),
+            pointing_to: new Gdk.Rectangle({x, y}),
             menu_model: section,
             has_arrow: false,
         });
@@ -892,7 +887,7 @@ class ChatView extends Gtk.ScrolledWindow {
         });
         indicator.add_css_class('dim-label');
 
-        let { buffer } = this._view;
+        let {buffer} = this._view;
         let iter = buffer.get_start_iter();
         let anchor = buffer.create_child_anchor(iter);
         this._view.add_child_at_anchor(indicator, anchor);
@@ -904,7 +899,7 @@ class ChatView extends Gtk.ScrolledWindow {
     }
 
     _hideLoadingIndicator() {
-        let { buffer } = this._view;
+        let {buffer} = this._view;
         let iter = buffer.get_start_iter();
 
         if (!iter.get_child_anchor())
@@ -918,7 +913,7 @@ class ChatView extends Gtk.ScrolledWindow {
         let lineStart = iter.copy();
         lineStart.set_line_offset(0);
 
-        let { buffer } = this._view;
+        let {buffer} = this._view;
         let mark = buffer.get_mark('indicator-line');
         if (mark) {
             let [start, end] = this._getLineIters(buffer.get_iter_at_mark(mark));
@@ -1078,7 +1073,7 @@ class ChatView extends Gtk.ScrolledWindow {
             return;
 
         this._view.buffer.delete_mark(markStart);
-        this._statusCount =  { left: 0, joined: 0, total: 0 };
+        this._statusCount =  {left: 0, joined: 0, total: 0};
         this._state.lastStatusGroup++;
     }
 
@@ -1093,7 +1088,7 @@ class ChatView extends Gtk.ScrolledWindow {
     }
 
     _updateStatusHeader() {
-        let { buffer } = this._view;
+        let {buffer} = this._view;
         let headerMark = buffer.get_mark('idle-status-start');
 
         let headerTagName = `status-compressed${this._state.lastStatusGroup}`;
@@ -1103,9 +1098,9 @@ class ChatView extends Gtk.ScrolledWindow {
         let headerTag, headerArrowTag, groupTag;
         if (!headerMark) {
             // we are starting a new group
-            headerTag = new ButtonTag({ name: headerTagName, invisible: true });
-            headerArrowTag = new Gtk.TextTag({ name: headerArrowTagName, invisible: true });
-            groupTag = new Gtk.TextTag({ name: groupTagName });
+            headerTag = new ButtonTag({name: headerTagName, invisible: true});
+            headerArrowTag = new Gtk.TextTag({name: headerArrowTagName, invisible: true});
+            groupTag = new Gtk.TextTag({name: groupTagName});
             buffer.tag_table.add(headerTag);
             buffer.tag_table.add(headerArrowTag);
             buffer.tag_table.add(groupTag);
@@ -1218,7 +1213,7 @@ class ChatView extends Gtk.ScrolledWindow {
         let daysAgo = todayMidnight.difference(dateMidnight) / GLib.TIME_SPAN_DAY;
 
         let format;
-        let desktopSettings = new Gio.Settings({ schema_id: 'org.gnome.desktop.interface' });
+        let desktopSettings = new Gio.Settings({schema_id: 'org.gnome.desktop.interface'});
         let clockFormat = desktopSettings.get_string('clock-format');
         let hasAmPm = date.format('%p') !== '';
 
@@ -1330,7 +1325,7 @@ class ChatView extends Gtk.ScrolledWindow {
                 let buffer = this._view.get_buffer();
 
                 if (!nickTag) {
-                    nickTag = new ButtonTag({ name: nickTagName });
+                    nickTag = new ButtonTag({name: nickTagName});
                     nickTag.connect('clicked', this._onNickTagClicked.bind(this));
 
                     let status = this._userTracker.getNickRoomStatus(message.nick, this._room);
@@ -1363,7 +1358,7 @@ class ChatView extends Gtk.ScrolledWindow {
         let params = this._room.account.dup_parameters_vardict().deep_unpack();
         let server = params.server.deep_unpack();
 
-        let { text } = message;
+        let {text} = message;
 
         // mask identify passwords in private chats
         if (this._room.type === Tp.HandleType.CONTACT) {
@@ -1389,7 +1384,7 @@ class ChatView extends Gtk.ScrolledWindow {
                 url.name, tags.concat(this._lookupTag('url'), tag));
 
             if (GLib.uri_parse_scheme(url.url).startsWith('http'))
-                previews.push(new URLPreview({ uri: url.url }));
+                previews.push(new URLPreview({uri: url.url}));
 
             pos = url.pos + url.name.length;
         }
