@@ -1,3 +1,13 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2015 Bastian Ilsø <bastianilso@gnome.org>
+// SPDX-FileCopyrightText: 2015 Kunaal Jain <kunaalus@gmail.com>
+// SPDX-FileCopyrightText: 2016 Isabella Ribeiro <belinhacbr@gmail.com>
+// SPDX-FileCopyrightText: 2016 raresv <rares.visalom@gmail.com>
+// SPDX-FileCopyrightText: 2016 Augusto Cesar <augusto.cms7@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -30,7 +40,7 @@ class ConnectionRow extends Gtk.ListBoxRow {
         if (!params || !params.id)
             throw new Error('No id in parameters');
 
-        const { id } = params;
+        const {id} = params;
         delete params.id;
 
         super(params);
@@ -52,7 +62,7 @@ class ConnectionRow extends Gtk.ListBoxRow {
         });
         this.set_child(box);
 
-        box.append(new Gtk.Label({ label: name, halign: Gtk.Align.START }));
+        box.append(new Gtk.Label({label: name, halign: Gtk.Align.START}));
 
         let insensitiveDesc = new Gtk.Label({
             label: _('Already added'),
@@ -83,7 +93,7 @@ class ConnectionsList extends Gtk.ScrolledWindow {
     };
 
     static [GObject.signals] = {
-        'account-created': { param_types: [Tp.Account.$gtype] },
+        'account-created': {param_types: [Tp.Account.$gtype]},
         'account-selected': {},
     };
 
@@ -179,7 +189,7 @@ class ConnectionsList extends Gtk.ScrolledWindow {
             w.run_dispose();
         });
 
-        let { accounts } = this._accountsMonitor;
+        let {accounts} = this._accountsMonitor;
         let usedNetworks = accounts.filter(a => a.predefined).map(a => a.service);
 
         this._networksManager.networks.forEach(network => {
@@ -247,14 +257,14 @@ class ConnectionsList extends Gtk.ScrolledWindow {
 });
 
 export const ConnectionDetails = GObject.registerClass(
-class ConnectionDetails extends Gtk.Box {
+class ConnectionDetails extends Adw.PreferencesPage {
     static [Gtk.template] = 'resource:///org/gnome/Polari/ui/connection-details.ui';
     static [Gtk.internalChildren] = [
         'nameRow',
         'serverRow',
         'nickRow',
         'realnameRow',
-        'sslSwitch',
+        'sslRow',
     ];
 
     static [GObject.properties] = {
@@ -269,7 +279,7 @@ class ConnectionDetails extends Gtk.Box {
     };
 
     static [GObject.signals] = {
-        'account-created': { param_types: [Tp.Account.$gtype] },
+        'account-created': {param_types: [Tp.Account.$gtype]},
     };
 
     _networksManager = NetworksManager.getDefault();
@@ -293,7 +303,7 @@ class ConnectionDetails extends Gtk.Box {
             row.connect('changed', this._onCanConfirmChanged.bind(this));
             row.get_delegate().activates_default = true;
         }
-        this._sslSwitch.connect('notify::active',
+        this._sslRow.connect('notify::active',
             this._onCanConfirmChanged.bind(this));
 
         const buffer = this._realnameRow.get_delegate().get_buffer();
@@ -346,7 +356,7 @@ class ConnectionDetails extends Gtk.Box {
 
         if (this._realnameRow.text)
             params.fullname = this._realnameRow.text.trim();
-        if (this._sslSwitch.active)
+        if (this._sslRow.active)
             params.use_ssl = true;
         if (port)
             params.port = port;
@@ -367,7 +377,7 @@ class ConnectionDetails extends Gtk.Box {
         this._serverRow.text = this._savedServer;
         this._nickRow.text = this._savedNick;
         this._realnameRow.text = this._savedRealname;
-        this._sslSwitch.active = this._savedSSL;
+        this._sslRow.active = this._savedSSL;
 
         if (this._serverRow.visible)
             this._serverRow.grab_focus();
@@ -382,7 +392,7 @@ class ConnectionDetails extends Gtk.Box {
     _populateFromAccount(account) {
         let params = account.getConnectionParams();
 
-        let { port } = params;
+        let {port} = params;
         this._savedSSL = params['use-ssl'];
         let defaultPort = this._savedSSL ? DEFAULT_SSL_PORT : DEFAULT_PORT;
         this._savedServer = params.server || '';
@@ -399,7 +409,7 @@ class ConnectionDetails extends Gtk.Box {
         this._nickRow.text = this._savedNick;
         this._realnameRow.text = this._savedRealname;
         this._nameRow.text = this._savedName;
-        this._sslSwitch.active = this._savedSSL;
+        this._sslRow.active = this._savedSSL;
     }
 
     // eslint-disable-next-line camelcase
@@ -408,7 +418,7 @@ class ConnectionDetails extends Gtk.Box {
                             this._serverRow.text !== this._savedServer ||
                             this._nickRow.text !== this._savedNick ||
                             this._realnameRow.text !== this._savedRealname ||
-                            this._sslSwitch.active !== this._savedSSL;
+                            this._sslRow.active !== this._savedSSL;
 
         return this._serverRow.text.length > 0 &&
                this._nickRow.text.length > 0 &&
@@ -498,19 +508,20 @@ class ConnectionDetails extends Gtk.Box {
 
 
 export const ConnectionProperties = GObject.registerClass(
-class ConnectionProperties extends Gtk.Dialog {
+class ConnectionProperties extends Adw.Window {
     static [Gtk.template] = 'resource:///org/gnome/Polari/ui/connection-properties.ui';
     static [Gtk.internalChildren] = [
+        'applyButton',
         'details',
         'errorBox',
         'errorLabel',
+        'view',
     ];
 
     constructor(account) {
         /* Translators: %s is a connection name */
         super({
             title: vprintf(_('“%s” Properties'), account.display_name),
-            use_header_bar: 1,
         });
 
         this._details.account = account;
@@ -525,11 +536,10 @@ class ConnectionProperties extends Gtk.Dialog {
             this.resize(this.default_width, 1);
         });
 
-        this.connect('response', (w, response) => {
-            if (response === Gtk.ResponseType.OK)
-                this._details.save();
+        this._applyButton.connect('clicked', () => {
+            this._details.save();
+            this.destroy();
         });
-        this.set_default_response(Gtk.ResponseType.OK);
 
         let id = account.connect('notify::connection-status',
             this._syncErrorMessage.bind(this));
@@ -542,8 +552,8 @@ class ConnectionProperties extends Gtk.Dialog {
         let status = account.connection_status;
         let reason = account.connection_status_reason;
 
-        this._errorBox.hide();
         this._details.setErrorHint(ErrorHint.NONE);
+        this._view.reveal_bottom_bars = false;
 
         if (status !== Tp.ConnectionStatus.DISCONNECTED ||
             reason === Tp.ConnectionStatusReason.REQUESTED)
@@ -552,9 +562,9 @@ class ConnectionProperties extends Gtk.Dialog {
         switch (account.connection_error) {
         case Tp.error_get_dbus_name(Tp.Error.CONNECTION_REFUSED):
         case Tp.error_get_dbus_name(Tp.Error.NETWORK_ERROR):
-            this._errorBox.show();
             this._errorLabel.label = _('Polari disconnected due to a network error. Please check if the address field is correct.');
             this._details.setErrorHint(ErrorHint.SERVER);
+            this._view.reveal_bottom_bars = true;
             break;
         }
     }
