@@ -1,3 +1,10 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2016 Kunaal Jain <kunaalus@gmail.com>
+// SPDX-FileCopyrightText: 2016 Isabella Ribeiro <belinhacbr@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -5,32 +12,24 @@ import Gtk from 'gi://Gtk';
 
 import AccountsMonitor from './accountsMonitor.js';
 
-const DialogPage = {
-    MAIN: 0,
-    CONNECTION: 1,
-};
-
 export default GObject.registerClass(
-class JoinDialog extends Gtk.Dialog {
+class JoinDialog extends Adw.Window {
     static [Gtk.template] = 'resource:///org/gnome/Polari/ui/join-room-dialog.ui';
     static [Gtk.internalChildren] = [
-        'cancelButton',
         'joinButton',
-        'mainStack',
+        'navView',
+        'mainPage',
+        'connectionPage',
+        'customPage',
         'connectionCombo',
-        'connectionButton',
-        'connectionStack',
         'filterEntry',
         'connectionsList',
         'serverRoomList',
         'details',
         'addButton',
-        'customToggle',
-        'backButton',
     ];
 
     constructor(params) {
-        params['use-header-bar'] = 1;
         super(params);
 
         this._setupMainPage();
@@ -45,31 +44,30 @@ class JoinDialog extends Gtk.Dialog {
         this._accountAddedId =
             this._accountsMonitor.connect('account-added', (am, account) => {
                 this._accounts.set(account.display_name, account);
-                this._updateConnectionCombo();
+                this._onAccountsChanged();
             });
         this._accountRemovedId =
             this._accountsMonitor.connect('account-removed', (am, account) => {
                 this._accounts.delete(account.display_name);
-                this._updateConnectionCombo();
+                this._onAccountsChanged();
             });
 
-        this.connect('response', (w, response) => {
-            if (response === Gtk.ResponseType.OK)
-                this._joinRoom();
-            this.destroy();
-        });
+        this._joinButton.connect('clicked',
+            () => this._joinRoom());
+
         this.connect('destroy', () => {
             this._accountsMonitor.disconnect(this._accountAddedId);
             this._accountsMonitor.disconnect(this._accountRemovedId);
         });
 
-        if (this._hasAccounts)
-            this._setPage(DialogPage.MAIN);
-        else
-            this._setPage(DialogPage.CONNECTION);
+        if (!this._hasAccounts)
+            this._navView.push(this._connectionPage);
 
-        this._updateConnectionCombo();
-        this._updateCanJoin();
+        this._navView.connect('notify::visible-page',
+            () => this._onPageChanged());
+
+        this._onAccountsChanged();
+        this._onPageChanged();
     }
 
     get _hasAccounts() {
@@ -77,10 +75,6 @@ class JoinDialog extends Gtk.Dialog {
     }
 
     _setupMainPage() {
-        this._connectionButton.connect('clicked', () => {
-            this._setPage(DialogPage.CONNECTION);
-        });
-
         this._connectionCombo.connect('changed',
             this._onAccountChanged.bind(this));
         this._connectionCombo.sensitive = false;
@@ -90,15 +84,12 @@ class JoinDialog extends Gtk.Dialog {
     }
 
     _setupConnectionPage() {
-        this._backButton.connect('clicked', () => {
-            this._setPage(DialogPage.MAIN);
-        });
         this._connectionsList.connect('account-selected', () => {
-            this._setPage(DialogPage.MAIN);
+            this._navView.pop_to_page(this._mainPage);
         });
         this._addButton.connect('clicked', () => {
             this._details.save();
-            this._setPage(DialogPage.MAIN);
+            this._navView.pop_to_page(this._mainPage);
         });
 
         this._connectionsList.connect('account-created',
@@ -106,16 +97,6 @@ class JoinDialog extends Gtk.Dialog {
         this._details.connect('account-created',
             this._onAccountCreated.bind(this));
 
-        this._customToggle.connect('notify::active', () => {
-            let isCustom = this._customToggle.active;
-            let childName = isCustom ? 'custom' : 'predefined';
-            this._connectionStack.visible_child_name = childName;
-            if (isCustom) {
-                this.set_default_widget(this._addButton);
-                this._details.reset();
-            }
-        });
-
         this._filterEntry.connect('search-changed', () => {
             this._connectionsList.setFilter(this._filterEntry.text);
         });
@@ -123,7 +104,7 @@ class JoinDialog extends Gtk.Dialog {
             if (this._filterEntry.text.length > 0)
                 this._filterEntry.text = '';
             else
-                this.response(Gtk.ResponseType.CANCEL);
+                this._navView.pop();
         });
         this._filterEntry.connect('activate', () => {
             if (this._filterEntry.text.length > 0)
@@ -163,9 +144,11 @@ class JoinDialog extends Gtk.Dialog {
                 true,
             ]));
         });
+
+        this.destroy();
     }
 
-    _updateConnectionCombo() {
+    _onAccountsChanged() {
         this._connectionCombo.remove_all();
 
         let names = [...this._accounts.keys()].sort((a, b) => {
@@ -181,42 +164,28 @@ class JoinDialog extends Gtk.Dialog {
         if (activeRoom)
             activeIndex = Math.max(names.indexOf(activeRoom.account.display_name), 0);
         this._connectionCombo.set_active(activeIndex);
+
+        this._connectionPage.set_can_pop(this._hasAccounts);
     }
 
     _updateCanJoin() {
         let sensitive = false;
 
-        if (this._page === DialogPage.MAIN) {
+        if (this._navView.visible_page === this._mainPage) {
             sensitive = this._connectionCombo.get_active() > -1  &&
                         this._serverRoomList.can_join;
         }
 
         this._joinButton.sensitive = sensitive;
-        this.set_default_response(sensitive
-            ? Gtk.ResponseType.OK : Gtk.ResponseType.NONE);
     }
 
-    get _page() {
-        if (this._mainStack.visible_child_name === 'connection')
-            return DialogPage.CONNECTION;
-        else
-            return DialogPage.MAIN;
-    }
-
-    _setPage(page) {
-        let isMain = page === DialogPage.MAIN;
-        let isAccountsEmpty = !this._hasAccounts;
-
-        if (isMain)
+    _onPageChanged() {
+        if (this._navView.visible_page === this._mainPage) {
             this._serverRoomList.focusEntry();
-        else
-            this._customToggle.active = false;
-
-        this._joinButton.visible = isMain;
-        this._cancelButton.visible = isMain || isAccountsEmpty;
-        this._backButton.visible = !(isMain || isAccountsEmpty);
-        this.title = isMain ? _('Join Chat Room') : _('Add Network');
-        this._mainStack.visible_child_name = isMain ? 'main' : 'connection';
+        } else if (this._navView.visible_page === this._customPage) {
+            this.set_default_widget(this._addButton);
+            this._details.reset();
+        }
         this._updateCanJoin();
     }
 });
