@@ -1,8 +1,12 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 import GLib from 'gi://GLib';
 
 import * as Config from './config.js';
-import { ngettext } from 'gettext';
-import { programInvocationName, programArgs } from 'system';
+import {ngettext} from 'gettext';
+import {programInvocationName, programArgs} from 'system';
 
 imports.package.init({
     name: Config.PACKAGE_NAME,
@@ -27,12 +31,8 @@ pkg.require({
     'TelepathyGLib': '0.12',
     'TelepathyLogger': '0.2',
 });
-pkg.requireSymbol('Gio', '2.0', 'Application.send_notification');
-pkg.requireSymbol('GLib', '2.0', 'log_variant');
-pkg.requireSymbol('Adw', '1', 'EntryRow');
-
-if (!pkg.checkSymbol('Soup', '3.0'))
-    pkg.requireSymbol('Soup', '2.4');
+pkg.requireSymbol('Adw', '1', 'ToolbarView');
+pkg.checkSymbol('Soup', '3.0');
 
 import Application from './application.js';
 
