@@ -1,3 +1,8 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2020 Philip Withnall <withnall@endlessm.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -14,78 +19,16 @@ import RoomStack_ from './roomStack.js'; // used in template
 import * as UserList_ from './userList.js'; // used in template
 import * as Utils from './utils.js';
 
-export const FixedSizeFrame = GObject.registerClass(
-class FixedSizeFrame extends Gtk.Widget {
-    static [GObject.properties] = {
-        height: GObject.ParamSpec.int(
-            'height', 'height', 'height',
-            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
-            -1, GLib.MAXINT32, -1),
-        width: GObject.ParamSpec.int(
-            'width', 'width', 'width',
-            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
-            -1, GLib.MAXINT32, -1),
-    };
-
-    constructor(params) {
-        super({
-            ...params,
-            layout_manager: new Gtk.BinLayout(),
-        });
-    }
-
-    _queueRedraw() {
-        const [child] = this;
-        child?.queue_resize();
-        this.queue_draw();
-    }
-
-    get height() {
-        return this._height;
-    }
-
-    set height(height) {
-        if (height === this._height)
-            return;
-        this._height = height;
-        this.notify('height');
-        this.set_size_request(this._width, this._height);
-        this._queueRedraw();
-    }
-
-    get width() {
-        return this._width;
-    }
-
-    set width(width) {
-        if (width === this._width)
-            return;
-
-        this._width = width;
-        this.notify('width');
-        this.set_size_request(this._width, this._height);
-        this._queueRedraw();
-    }
-
-    vfunc_measure(orientation, forSize) {
-        const fixedSize = orientation === Gtk.Orientation.HORIZONTAL
-            ? this._width : this._height;
-        const [min, nat] = super.vfunc_measure(orientation, forSize);
-        return [min, fixedSize < 0 ? nat : fixedSize, -1, -1];
-    }
-});
-
 export default GObject.registerClass(
 class MainWindow extends Adw.ApplicationWindow {
     static [Gtk.template] = 'resource:///org/gnome/Polari/ui/main-window.ui';
     static [Gtk.internalChildren] = [
-        'backButton',
         'joinButton',
-        'mainLeaflet',
+        'splitView',
         'showUserListButton',
         'userListPopover',
         'roomListRevealer',
-        'offlineInfoBar',
+        'offlineBanner',
         'overlay',
         'roomStack',
     ];
@@ -115,7 +58,7 @@ class MainWindow extends Adw.ApplicationWindow {
 
     _lastActiveRoom = null;
 
-    _settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
+    _settings = new Gio.Settings({schema_id: 'org.gnome.Polari'});
 
     _currentSize = [-1, -1];
     _isMaximized = false;
@@ -139,10 +82,6 @@ class MainWindow extends Adw.ApplicationWindow {
 
         this._roomStack.connect('notify::view-height',
             () => this.notify('view-height'));
-        this._roomStack.connect('notify::visible-child',
-            () => this._mainLeaflet.navigate(Adw.NavigationDirection.FORWARD));
-        this._backButton.connect('clicked',
-            () => this._mainLeaflet.navigate(Adw.NavigationDirection.BACKWARD));
 
         this._accountsMonitor = AccountsMonitor.getDefault();
         this._accountsChangedId = this._accountsMonitor.connect(
@@ -219,7 +158,7 @@ class MainWindow extends Adw.ApplicationWindow {
 
     _onAccountsReachableChanged() {
         let accounts = this._accountsMonitor.visibleAccounts;
-        this._offlineInfoBar.revealed =
+        this._offlineBanner.revealed =
             accounts.length > 0 && !accounts.some(a => a.reachable);
     }
 
@@ -336,7 +275,7 @@ class MainWindow extends Adw.ApplicationWindow {
     }
 
     showJoinRoomDialog() {
-        let dialog = new JoinDialog({ transient_for: this });
+        let dialog = new JoinDialog({transient_for: this});
         dialog.show();
     }
 
