@@ -1,9 +1,16 @@
+/*
+ * SPDX-FileCopyrightText: 2016 Florian Müllner <fmuellner@gnome.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include <girepository.h>
 #include <gjs/gjs.h>
 
 #include "config.h"
 
+#ifndef GJS_HAS_AUTOCLEANUP
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GjsContext, g_object_unref)
+#endif
 
 #define JS_MAIN "resource:///org/gnome/Polari/js/main.js"
 
