@@ -1,3 +1,11 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2015 Bastian Ilsø <bastianilso@gnome.org>
+// SPDX-FileCopyrightText: 2016 Isabella Ribeiro <belinhacbr@gmail.com>
+// SPDX-FileCopyrightText: 2016 raresv <rares.visalom@gmail.com>
+// SPDX-FileCopyrightText: 2018 unkemptArc99 <abhishekbhardwaj540@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 import Gdk from 'gi://Gdk';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -32,6 +40,8 @@ class RoomRow extends Gtk.ListBoxRow {
     constructor(room) {
         super({
             name: `RoomRow ${room.display_name}`,
+            actionName: 'navigation.push',
+            actionTarget: new GLib.Variant('s', 'content'),
         });
 
         this._room = room;
@@ -42,9 +52,9 @@ class RoomRow extends Gtk.ListBoxRow {
 
         this._connectingTimeoutId = 0;
 
-        this._mutedIcon = new Gio.EmblemedIcon({ gicon: room.icon });
+        this._mutedIcon = new Gio.EmblemedIcon({gicon: room.icon});
         this._mutedIcon.add_emblem(new Gio.Emblem({
-            icon: new Gio.ThemedIcon({ name: 'emblem-unreadable' }),
+            icon: new Gio.ThemedIcon({name: 'emblem-unreadable'}),
         }));
 
         this._icon.visible = room.icon !== null;
@@ -163,10 +173,13 @@ class RoomRow extends Gtk.ListBoxRow {
     }
 
     _onMutedChanged() {
-        if (this.muted)
+        if (this.muted) {
             this._icon.gicon = this._mutedIcon;
-        else
+            this.add_css_class('muted');
+        } else {
             this._icon.gicon = this.room.icon;
+            this.remove_css_class('muted');
+        }
 
         this._updatePending();
     }
@@ -312,7 +325,7 @@ class RoomListHeader extends Gtk.Widget {
     };
 
     static [GObject.signals] = {
-        'activate': { flags: GObject.SignalFlags.ACTION },
+        'activate': {flags: GObject.SignalFlags.ACTION},
     };
 
     static _classInit(klass) {
@@ -325,7 +338,7 @@ class RoomListHeader extends Gtk.Widget {
     }
 
     constructor(params) {
-        const { account } = params;
+        const {account} = params;
         delete params.account;
 
         super({
@@ -410,12 +423,6 @@ class RoomListHeader extends Gtk.Widget {
         });
     }
 
-    vfunc_unroot() {
-        [...this].forEach(child => child.unparent());
-
-        super.vfunc_unroot();
-    }
-
     get popover() {
         return this._popover;
     }
@@ -504,7 +511,7 @@ class RoomListHeader extends Gtk.Widget {
             let accountName = this._account.display_name;
 
             /* Translators: This is an account name followed by a
-               server address, e.g. "GNOME (irc.gnome.org)" */
+               server address, e.g. "Libera (irc.libera.chat)" */
             let fullTitle = vprintf(_('%s (%s)'), accountName, server);
             this._popoverTitle.label = accountName === server ? accountName : fullTitle;
             this._popoverStatus.label = this._getStatusLabel();
@@ -673,7 +680,7 @@ class RoomList extends Gtk.ListBox {
 
     _roomToRowIndex(index) {
         let roomRows = [...this].filter(r => r instanceof RoomRow);
-        return index < roomRows.length ? roomRows[index].get_index() : -1;
+        return index >= 0 && index < roomRows.length ? roomRows[index].get_index() : -1;
     }
 
     _getRoomRowAtIndex(index) {
@@ -823,8 +830,8 @@ class RoomList extends Gtk.ListBox {
     }
 
     _updateHeader(row, before) {
-        let { account: beforeAccount } = before || {};
-        let { account } = row;
+        let {account: beforeAccount} = before || {};
+        let {account} = row;
 
         let oldHeader = row.get_header();
 
@@ -838,7 +845,7 @@ class RoomList extends Gtk.ListBox {
         if (oldHeader)
             return;
 
-        let roomListHeader = new RoomListHeader({ account });
+        let roomListHeader = new RoomListHeader({account});
         row.set_header(roomListHeader);
     }
 
