@@ -1,3 +1,8 @@
+// SPDX-FileCopyrightText: 2013 Florian Müllner <fmuellner@gnome.org>
+// SPDX-FileCopyrightText: 2019 Daronion <stefanosdimos.98@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -88,7 +93,7 @@ class SASLAuthHandler {
                 'Password not available');
 
             let prompt = new GLib.Variant('b', false);
-            let params = new GLib.Variant('a{sv}', { 'password-prompt': prompt });
+            let params = new GLib.Variant('a{sv}', {'password-prompt': prompt});
             await account.update_parameters_vardict_async(params, []);
             await account.request_presence_async(Tp.ConnectionPresenceType.AVAILABLE,
                 'available', '', null);
@@ -363,7 +368,7 @@ class TelepathyClient extends Tp.BaseClient {
         } finally {
             const room = this._roomManager.lookupRoom(roomId);
             if (room)
-                room.set({ channelError });
+                room.set({channelError});
             this._pendingRequests.delete(roomId);
         }
 
@@ -371,7 +376,7 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     async _sendIdentify(account, password) {
-        let { settings } = account;
+        let {settings} = account;
 
         let params = account.dup_parameters_vardict().deep_unpack();
         let username = settings.get_string('identify-username') ||
@@ -432,7 +437,7 @@ class TelepathyClient extends Tp.BaseClient {
         let account = this._accountsMonitor.lookupAccount(accountPath);
 
         let prompt = new GLib.Variant('b', password.length > 0);
-        let params = GLib.Variant.new('a{sv}', { 'password-prompt': prompt });
+        let params = GLib.Variant.new('a{sv}', {'password-prompt': prompt});
         await account.update_parameters_vardict_async(params, []);
         await Utils.storeAccountPassword(account, password);
         await account.reconnect_async();
@@ -515,7 +520,7 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     _saveIdentifySettings(account, data) {
-        let { settings } = account;
+        let {settings} = account;
 
         if (data.botname === 'NickServ')
             settings.reset('identify-botname');
@@ -678,7 +683,7 @@ class TelepathyClient extends Tp.BaseClient {
 
         let accountName = room.account.display_name;
         /* Translators: Those are a botname and an accountName, e.g.
-           "Save NickServ password for GNOME" */
+           "Save NickServ password for Libera" */
         let summary = vprintf(_('Save %s password for %s?'), data.botname, accountName);
         let text = vprintf(
             _('Identification will happen automatically the next time you connect to %s'), accountName);
